import os

from mailgun.client import Client


key: str = os.environ["APIKEY"]
domain: str = os.environ["DOMAIN"]
client: Client = Client(auth=("api", key))


def post_analytics_logs() -> None:
    """
    # Metrics
    # POST /v1/analytics/logs
    :return:
    """

    data = {
        "start": "Wed, 24 Sep 2025 00:00:00 +0000",
        "end": "Thu, 25 Sep 2025 00:00:00 +0000",
        "filter": {
            "AND": [
                {
                    "attribute": "domain",
                    "comparator": "=",
                    "values": [{"label": domain, "value": domain}],
                }
            ]
        },
        "include_subaccounts": True,
        "pagination": {
            "sort": "timestamp:asc",
            "limit": 50,
        },
    }

    req = client.analytics_logs.create(data=data)
    print(req.json())


if __name__ == "__main__":
    post_analytics_logs()



import os

from mailgun.client import Client


key: str = os.environ["APIKEY"]
domain: str = os.environ["DOMAIN"]

client: Client = Client(auth=("api", key))


def post_template() -> None:
    """
    POST /<domain>/templates
    :return:
    """
    data = {
        "name": "template.name1",
        "description": "template description",
        "template": "{{fname}} {{lname}}",
        "engine": "handlebars",
        "comment": "version comment",
    }

    req = client.templates.create(data=data, domain=domain)
    print(req.json())


def get_template() -> None:
    """
    GET /<domain>/templates/<name>
    :return:
    """
    params = {"active": "yes"}
    req = client.templates.get(domain=domain, filters=params, template_name="template.name1")
    print(req.json())


def update_template() -> None:
    """
    PUT /<domain>/templates/<name>
    :return:
    """
    data = {"description": "new template description"}

    req = client.templates.put(data=data, domain=domain, template_name="template.name1")
    print(req.json())


def delete_template() -> None:
    """
    DELETE /<domain>/templates/<name>
    :return:
    """
    req = client.templates.delete(domain=domain, template_name="template.name1")
    print(req.json())


def get_domain_templates() -> None:
    """
    GET /<domain>/templates
    :return:
    """
    params = {"limit": 1}
    req = client.templates.get(domain=domain, filters=params)
    print(req.json())


def delete_templates() -> None:
    """
    DELETE /<domain>/templates
    :return:
    """
    req = client.templates.delete(domain=domain)
    print(req.json())


def create_new_template_version() -> None:
    """
    POST /<domain>/templates/<template>/versions
    :return:
    """
    data = {
        "tag": "v1",
        "template": "{{fname}} {{lname}}",
        "engine": "handlebars",
        "active": "yes",
    }

    req = client.templates.create(
        data=data, domain=domain, template_name="template.name1", versions=True
    )
    print(req.json())


def get_template_version() -> None:
    """
    GET /<domain>/templates/<name>/versions/<tag>
    :return:
    """
    req = client.templates.get(
        domain=domain, template_name="template.name1", versions=True, tag="v1"
    )
    print(req.json())


def update_template_version() -> None:
    """
    PUT /<domain>/templates/<name>/versions/<tag>
    :return:
    """
    data = {"template": "{{fname}} {{lname}}", "comment": "Updated version comment"}

    req = client.templates.put(
        domain=domain,
        data=data,
        template_name="template.name1",
        versions=True,
        tag="v1",
    )
    print(req.json())


def delete_template_version() -> None:
    """
    DELETE /<domain>/templates/<template>/versions/<version>
    :return:
    """
    req = client.templates.delete(
        domain=domain, template_name="template.name1", versions=True, tag="initial"
    )
    print(req.json())


def get_all_versions() -> None:
    """
    GET /<domain>/templates/<template>/versions
    :return:
    """
    req = client.templates.get(domain=domain, template_name="template.name1", versions=True)
    print(req.json())


if __name__ == "__main__":
    get_all_versions()



import os

from mailgun.client import Client


key: str = os.environ["APIKEY"]
domain: str = os.environ["DOMAIN"]
client: Client = Client(auth=("api", key))


def post_list_statistic_v2() -> None:
    """
    # Bounce Classification
    # POST /v2/bounce-classification/metrics
    :return:
    """

    payload = {
        "start": "Wed, 12 Nov 2025 23:00:00 UTC",
        "end": "Thu, 13 Nov 2025 23:00:00 UTC",
        "resolution": "day",
        "duration": "24h0m0s",
        "dimensions": ["entity-name", "domain.name"],
        "metrics": [
            "critical_bounce_count",
            "non_critical_bounce_count",
            "critical_delay_count",
            "non_critical_delay_count",
            "delivered_smtp_count",
            "classified_failures_count",
            "critical_bounce_rate",
            "non_critical_bounce_rate",
            "critical_delay_rate",
            "non_critical_delay_rate",
        ],
        "filter": {
            "AND": [
                {
                    "attribute": "domain.name",
                    "comparator": "=",
                    "values": [{"value": domain}],
                }
            ]
        },
        "include_subaccounts": True,
        "pagination": {"sort": "entity-name:asc", "limit": 10},
    }

    headers = {"Content-Type": "application/json"}

    req = client.bounceclassification_metrics.create(data=payload, headers=headers)
    print(req.json())


if __name__ == "__main__":
    post_list_statistic_v2()



import os

from mailgun.client import Client


key: str = os.environ["APIKEY"]
domain: str = os.environ["DOMAIN"]
client: Client = Client(auth=("api", key))


def post_analytics_tags() -> None:
    """
    # Metrics
    # POST /v1/analytics/tags
    :return:
    """

    data = {
        "pagination": {"sort": "lastseen:desc", "limit": 10},
        "include_subaccounts": True,
    }

    req = client.analytics_tags.create(data=data)
    print(req.json())


def update_analytics_tags() -> None:
    """
    # Metrics
    # PUT /v1/analytics/tags
    :return:
    """

    data = {
        "tag": "name-of-tag-to-update",
        "description": "updated tag description",
    }

    req = client.analytics_tags.update(data=data)
    print(req.json())


def delete_analytics_tags() -> None:
    """
    # Metrics
    # DELETE /v1/analytics/tags
    :return:
    """

    data = {"tag": "name-of-tag-to-delete"}

    req = client.analytics_tags.delete(data=data)
    print(req.json())


def get_account_analytics_tag_limit_information() -> None:
    """
    # Metrics
    # GET /v1/analytics/tags/limits
    :return:
    """

    req = client.analytics_tags_limits.get()
    print(req.json())


if __name__ == "__main__":
    post_analytics_tags()
    update_analytics_tags()
    delete_analytics_tags()
    get_account_analytics_tag_limit_information()



"""The `mailgun` package provides a Python SDK for interacting with the Mailgun API.

Packages:
    - examples: basic examples.
    - handlers: predefined handlers.

Modules:
    - client: Defines the main API client.

"""



import os

from mailgun.client import Client


key: str = os.environ["APIKEY"]
domain: str = os.environ["DOMAIN"]

client: Client = Client(auth=("api", key))


def get_routes() -> None:
    """
    GET /routes
    :return:
    """
    params = {"skip": 0, "limit": 1}
    req = client.routes.get(domain=domain, filters=params)
    print(req.json())


def get_route_by_id() -> None:
    """
    GET /routes/<id>
    :return:
    """
    req = client.routes.get(domain=domain, route_id="6012d994e8d489e24a127e79")
    print(req.json())


def post_routes() -> None:
    """
    POST /routes
    :return:
    """
    data = {
        "priority": 0,
        "description": "Sample route",
        "expression": f"match_recipient('.*@{domain}')",
        "action": ["forward('http://myhost.com/messages/')", "stop()"],
    }
    req = client.routes.create(domain=domain, data=data)
    print(req.json())


def put_route() -> None:
    """
    PUT /routes/<id>
    :return:
    """
    data = {
        "priority": 2,
        "description": "Sample route",
        "expression": f"match_recipient('.*@{domain}')",
        "action": ["forward('http://myhost.com/messages/')", "stop()"],
    }
    req = client.routes.put(domain=domain, data=data, route_id="60142b357c90c3c9f228e0a6")
    print(req.json())


def delete_route() -> None:
    """
    DELETE /routes/<id>
    :return:
    """
    req = client.routes.delete(domain=domain, route_id="60142b357c90c3c9f228e0a6")
    print(req.json())


if __name__ == "__main__":
    delete_route()
